@@ -9,9 +9,9 @@
 
 port <- 80
 test2 <- list(
-            fruit="apple"
+            "fruit"="apple"
            ,"dat_defs"="20021204/F113213.dat"
-           ,upsa="test"
+           ,"upsa"="test"
            )
            print(test2)
 PostToHost("127.0.0.1","/cgi-bin/param_list.pl",test2,referer="www.test.de",port=port)
@@ -22,9 +22,9 @@ PostToHost("127.0.0.1","/cgi-bin/param_list.pl",test2,referer="www.test.de",port
 ##==============================================================
 
 
-  port <- 80
-  data = "pid=14&poll_vote_number=2\n4";
-  SimplePostToHost("127.0.0.1","/cgi-bin/param_list.pl","http://www.linux.com/polls/index.phtml?pid=1415",data,port=port)
+port <- 80
+data = "pid=14&poll_vote_number=2";
+SimplePostToHost("127.0.0.1","/cgi-bin/param_list.pl","http://www.linux.com/polls/index.phtml?pid=1415",data,port=port)
 
 
 ##==============================================================
